@@ -32,7 +32,6 @@
 #define HIDE_REASON_HYDROGEN        8
 #define HIDE_REASON_QPEAK          16 
 
-
 /*! \brief ChGL is the QGLWidget of ShelXle
  */
 class ChGL : public QGLWidget{
@@ -133,8 +132,20 @@ signals:
     void neuemitte(V3 mitte);//!< the rotation center has changet to mitte.
     void inimibas();//!< tells FourXle to initialize the GL display lists.
     void qpfoci(double height);//!< when a mouse hovers a Q-Peak the height is emitted to the Q-Peak Legend.
-public slots:
+    void insertDFIX(double value, double esd, QList<MyAtom> selected, QString resiSpec); //!< Insert DFIX restrain to the ins file
+    void insertDANG(double value, double esd, QList<MyAtom> selected, QString resiSpec); //!< Insert DANG restrain to the ins file
+    void insertFLAT(double esd, QList<MyAtom> selected, QString resiSpec); //!< Insert FLAT restrain to the ins file
+    void insertEXYZ(QList<MyAtom> selected); //!< Insert EXYZ restrain to the ins file
+    void insertEADP(QList<MyAtom> selected); //!< Insert EADP restrain to the ins file
+    void insertDELU(double esd1, double esd2, QList<MyAtom> selected, QString resiSpec); //!< Insert DELU restrain to the ins file
+    void insertSIMU(double esd1, double st, double dmax, QList<MyAtom> selected, QString resiSpec); //!< Insert SIMU restrain to the ins file
+    void insertISOR(double esd1, double esd2, QList<MyAtom> selected, QString resiSpec); //!< Insert ISOR restrain to the ins file
+    void insertRIGU(double esd1, double esd2, QList<MyAtom> selected, QString resiSpec); //!< Insert DELU restrain to the ins file
+    void insertCHIV(double Vol, double esd1, QList<MyAtom> selected, QString resiSpec); //!< Insert CHIV restrain to the ins file
+    void insertANIS(QList<MyAtom> selected); //!< Insert ANIS instruction for selected atoms
 
+public slots:
+    void along001(); 
     void anaglyphRedCyan();
     void changeBColor();
     void changeEnviRange();
@@ -190,13 +201,26 @@ public slots:
     void setViewAngle(double ang);
     void setXRayView(bool b);
     void showHidden();
+    void showMatrix();
+    void zoomOut();
     void unsetTube(bool b){
       //!sets tube mode to not b
       tubes=!b;
       updateGL();
     }
     void zalman();
-
+// Restrain slots
+    void addDFIX(); 
+    void addDANG(); 
+    void addFLAT(); 
+    void addEXYZ(); 
+    void addEADP(); 
+    void addDELU(); 
+    void addSIMU(); 
+    void addISOR();
+    void addRIGU();
+    void addCHIV();
+    void addANIS();
 
 protected:
    void initializeGL();
@@ -232,6 +256,7 @@ private:
         double qcutoff,pickradius;
 	int frid;
         QPoint lastPos;
+    QStringList resis();
 };
 
 #endif // CHGL_H
