@@ -22,9 +22,7 @@
 #else
 #include <GL/glu.h>
 #endif
-#ifndef PROGRAM_NAME
-#define PROGRAM_NAME "shelXle"
-#endif
+#include "itsme.h"
 /*
    extern void __RotateCS( double c, double s, double& X, double& Y );
    extern void glTranslateL( const double dx, const double dy, const double dz );
